% FINDAREA - Script finds surface area for a triangulated surface,
%            given in workspace variables X, Y, Z, FACELIST

% Philip D Loewen, 2011-02-15

% Get number of triangles in facelist
[Ntri,three] = size(FACELIST);

% Set up an area accumulator
TotalArea = 0;

% Loop to visit each triangle
for i=1:Ntri
  % Get vertex coordinates for triangle number i 
  Xtri = X(FACELIST(i,:));
  Ytri = Y(FACELIST(i,:));
  Ztri = Z(FACELIST(i,:));

  % Find a normal vector whose length equals triangle area
  N   = n_dS(Xtri,Ytri,Ztri);

  % Accumulate area contributed by triangle number i
  TotalArea = TotalArea + norm(N);
end

% Announce results and stop
disp(sprintf( 'Current surface has %d triangles, area %7.4f.',[Ntri,TotalArea]));

