% MAKESPHERE - generate a triangulated sphere of given radius

% Philip D Loewen, 2010-02-19

function [FACES,X,Y,Z] = makesphere(R,N)

if N<3
    disp('Warning: Bad subinterval count; using default instead.')
    N = 3;
end

if R<eps
    disp('Warning: Bad sphere radius; using default (1) instead.');
    R = 1;
end;

nodes = 1 + round(N);

[T,P] = meshgrid(linspace(0,2*pi,nodes), linspace(0,pi,nodes));
THETA = T(:); clear T
PHI   = P(:); clear P

FACES = delaunay(THETA,PHI);

X = R * cos(THETA) .* sin(PHI);
Y = R * sin(THETA) .* sin(PHI);
Z = R * cos(PHI);
