% SETUP0  -  script records physical and boat-specific parameters
%            in global variables, prints pretty table for confirmation.

% Philip D Loewen, 2009-03-10; 2010-03-04; 2011-03-05

% Identification information in text strings

MYNAME    = 'Loewen';
TRIALNAME = 'Heavy cargo with 100g driving';

% Lengths and areas for my foam boat

global BOATLENGTH_L WETTEDSURFACE_S FRONTAREA_A DRAGCOEFFICIENT
BOATLENGTH_L    = 0.25;           % Boat's length, m
FRONTAREA_A     = 0.0040;         % Boat's projected front area, m^2
WETTEDSURFACE_S = 0.048;          % Boat's wetted surface area, m^2
DRAGCOEFFICIENT = 1;              % A pure guess (dimensionless)

% Masses related to this experiment

global FALLINGMASS LOADEDBOATMASS
LOADEDBOATMASS = 0.058 + 0.840;   % Boat mass plus cargo mass, kg
FALLINGMASS    = 0.100;           % Mass of falling pulley stage plus weights, kg

%%%%%%%% END OF STUDENT INPUT SECTION (JUST READ THE REST)

% Parameters for the drag expression  alpha+beta*v^p
global EXPONENT_P PARAMETER_ALPHA PARAMETER_BETA
EXPONENT_P = 4;                   % Maybe this needs adjusting!
PARAMETER_ALPHA = 1;              % This *definitely* ne
PARAMETER_BETA  = 1;

% Physical constants (no need to change these)

global GRAVITY WATERDENSITY KINEMATICVISCOSITY
GRAVITY = 9.8;                    % Acceleration of gravity, m/s^2
WATERDENSITY = 1000;              % Water density, kg/m^3
KINEMATICVISCOSITY = 1.15E-6;     % Kinematic viscosity (nu) for water at 15C

% Print report [optional]
% To turn off the report, create a workspace variable REPORT and
% give it a value of 0 or smaller. If you pay no attention to this,
% and variable REPORT is undefined, the report will print.

if (~exist('REPORT') | REPORT>0)

disp(['=================================================']);
disp(['  ',TRIALNAME,' (',MYNAME,')']);
disp(['=================================================']);
disp(sprintf('BOATLENGTH_L:       %6.4f   m',    BOATLENGTH_L));
disp(sprintf('FRONTAREA_A:        %6.4f   m^2',  FRONTAREA_A));
disp(sprintf('WETTEDSURFACE_S:    %6.4f   m^2',  WETTEDSURFACE_S));
disp(sprintf('DRAGCOEFFICIENT:    %6.4f',        DRAGCOEFFICIENT));
disp(sprintf('LOADEDBOATMASS:     %6.4f   kg',   LOADEDBOATMASS));
disp(sprintf('FALLINGMASS:        %6.4f   kg',   FALLINGMASS));
disp(sprintf('GRAVITY:            %6.4f   m/s^2',GRAVITY));
disp(sprintf('WATERDENSITY:       %7.2e kg/m^3', WATERDENSITY));
disp(sprintf('KINEMATICVISCOSITY: %7.2e m^2/s',  KINEMATICVISCOSITY));
disp(sprintf('EXPONENT_P:         %6.4f',        EXPONENT_P));
disp(sprintf('PARAMETER_ALPHA:    %6.4f',        PARAMETER_ALPHA));
disp(sprintf('PARAMETER_BETA:     %6.4f',        PARAMETER_BETA));
disp(['=================================================']);

end;
